#!/usr/bin/env python

##*****************************************************************************
##
## File: listAllServers.py
##
## Copyright (c) 2016 Autodesk, Inc.
## All rights reserved.
##
## Use of this software is subject to the terms of the Autodesk license
## agreement provided at the time of installation or download, or which
## otherwise accompanies this software in either electronic or hard copy form.
##
##*****************************************************************************

"""
Wiretap SDK python sample program to list all Wiretap servers.
"""

from __future__ import print_function
from __future__ import absolute_import

from adsk.libwiretapPythonClientAPI import WireTapClient
from adsk.libwiretapPythonClientAPI import WireTapServerList
from adsk.libwiretapPythonClientAPI import WireTapServerInfo
from adsk.libwiretapPythonClientAPI import WireTapInt


class WireTapException(Exception):
    pass


def main():

    # Initialize the Wiretap Client API.
    #
    wiretap_client = WireTapClient()
    if not wiretap_client.init():
        raise WireTapException("Unable to initialize Wiretap client API.")

    list_all_servers()


def list_all_servers():

    # Obtain the list of Wiretap servers.
    #
    server_list = WireTapServerList()
    num_servers = WireTapInt()
    if not server_list.getNumNodes(num_servers):
        raise WireTapException(
            "Error acquiring server list: %s." % server_list.lastError()
        )

    print("Server                IP address  Storage Id     Protocol")
    print("---------------------------------------------------------")

    # Obtain information about each server.
    #
    for server_index in range(0, num_servers):
        server_info = WireTapServerInfo()
        if not server_list.getNode(server_index, server_info):
            raise WireTapException(
                "Error accessing server %d: %s."
                % (server_index, server_list.lastError())
            )

        print(
            "%-16s %15s  %-16s %d.%d"
            % (
                server_info.getDisplayName(),
                server_info.getHostname(),
                server_info.getStorageId(),
                server_info.getVersionMajor(),
                server_info.getVersionMinor(),
            )
        )


if __name__ == "__main__":
    main()
