#!/usr/bin/env python

##*****************************************************************************
##
## File: test.py
##
## Copyright (c) 2016 Autodesk, Inc.
## All rights reserved.
##
## Use of this software is subject to the terms of the Autodesk license
## agreement provided at the time of installation or download, or which
## otherwise accompanies this software in either electronic or hard copy form.
##
##*****************************************************************************

"""
Wiretap SDK sample python program ping a server.
"""

from __future__ import print_function
from __future__ import absolute_import

import sys
import getopt

from adsk.libwiretapPythonClientAPI import WireTapClient
from adsk.libwiretapPythonClientAPI import WireTapServerHandle


class WireTapException(Exception):
    pass


def main(argv):
    # check the command line options for correctness
    try:
        opts, _ = getopt.getopt(argv, "h:")
    except getopt.GetoptError:
        print("Usage:\n" "-h <hostname>\n")
        sys.exit(2)

    # default host name
    host_name = "localhost"

    # parse command line option to set specified host name
    for opt, arg in opts:
        if opt == "-h":
            host_name = arg

    # Initialize the Wiretap Client API.
    wiretap_client = WireTapClient()
    if not wiretap_client.init():
        raise WireTapException("Unable to initialize Wiretap client API.")

    ping_test(host_name)


def ping_test(host_name):
    try:
        # Instantiate a server handle, and traverse.
        server_handle = WireTapServerHandle(host_name)

        # Ping test.
        if not server_handle.ping():
            raise WireTapException(
                "Ping to host: '%s' failed: %s."
                % (host_name, server_handle.lastError())
            )
        print("Ping of host: '%s' successful." % host_name)
    finally:
        # Must be destroyed before the Wiretap Client API is uninitialized
        server_handle = None


if __name__ == "__main__":
    main(sys.argv[1:])
