#!/usr/bin/env python

#
# Wiretap SDK tool for obtaining the type of a node.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
    WireTapInt,
    WireTapStr,
)


def printUsage():
    print("Usage:\n" "-n <node Id>\n" "[-h <hostname>]\n" "[-s] print type string\n")


def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:n:s")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variables (to be set from command line arguments).
    # For hostName, the default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"
    nodeId = ""
    printString = 0

    # Parse command line and set variables just declared.
    #
    for opt, arg in opts:
        if opt == "-h":
            hostName = arg
        elif opt == "-n":
            nodeId = arg
        elif opt == "-s":
            printString = 1

    if nodeId == "":
        print("Node ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate the node and get its type.
        #
        node = WireTapNodeHandle(server, nodeId)

        if printString:
            nodeType = WireTapStr()
            if not node.getNodeTypeStr(nodeType):
                raise Exception("Unable to retrieve node type: %s" % node.lastError())
            print(nodeType.c_str())

        else:
            nodeType = WireTapInt()
            if not node.getNodeType(nodeType):
                raise Exception("Unable to retrieve node type: %s" % node.lastError())
            print(int(nodeType))

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None


if __name__ == "__main__":
    main()
