#!/usr/bin/env python

#
# Wiretap SDK tool for getting the root node of a Wiretap server.
#

from __future__ import print_function

import getopt
import sys

from libwiretapPythonClientAPI import (
    WireTapClient,
    WireTapServerHandle,
    WireTapNodeHandle,
)


def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "h:")
    except getopt.GetoptError:
        print("Usage:\n" "-h <hostname>\n")
        return 2

    # Declare variable for hostName.
    # The default "localhost" will work if a Wiretap server
    # is running on your machine.
    #
    hostName = "localhost"

    # Parse command line and set value for hostName.
    #
    for opt, arg in opts:
        if opt == "-h":
            hostName = arg

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server handle
        #
        server = WireTapServerHandle(hostName)

        # Instantiate a node and set it to the root node obtained from the server
        #
        node = WireTapNodeHandle()
        if not server.getRootNode(node):
            raise Exception("Unable to retrieve root node: %s " % server.lastError())

        print(node.getNodeId().id())

    finally:
        # Must destroy WireTapServerHandle and WireTapNodeHandle before
        # uninitializing the Wiretap Client API.
        #
        node = None
        server = None

    return 0


if __name__ == "__main__":
    exitCode = main()
    sys.exit(exitCode)
