#!/usr/bin/env python

#
# Wiretap SDK tool for resolving a storage ID (unique identifier for
# a storage device) into a Wiretap server ID.
#

from __future__ import print_function

import getopt
import sys
from libwiretapPythonClientAPI import WireTapClient, WireTapServerList, WireTapServerId


def printUsage():
    print("Usage:\n[-s] <Storage ID>\n")


def main():

    # Check the command line options for correctness.
    try:
        opts, _ = getopt.getopt(sys.argv, "s:")
    except getopt.GetoptError:
        printUsage()
        sys.exit(2)

    # Declare variable (to be set from command line).
    storageId = ""

    # Parse command line and set variable just declared.
    for opt, arg in opts:
        if opt == "-s":
            storageId = arg

    if storageId == "":
        print("Storage ID not specified.\n")
        printUsage()
        sys.exit(2)

    # Initialize the Wiretap Client API.
    #
    wiretapClient = WireTapClient()
    if not wiretapClient.init():
        raise Exception("Unable to initialize Wiretap client API")

    try:
        # Instantiate a server list object which can resolve the given storage ID
        # (to get the ID of the Wiretap server to which the storage device
        # is connected).
        #
        serverList = WireTapServerList()
        server = WireTapServerId()
        server.setStorageId(storageId)
        if not serverList.resolve(server):
            raise Exception(serverList.lastError())

        # Display the result.
        #
        print(server.getIPAddr())

    finally:
        # Must destroy WireTapServerList before uninitializing the
        # Wiretap Client API.
        #
        server = None


if __name__ == "__main__":
    main()
